@@ -16,6 +16,7 @@
 
 import feedparser, pickle, os, sys, twitter, urllib
 from ConfigParser import ConfigParser, NoOptionError
+from options import Options
 import readrss
 import re
 import time
@@ -80,10 +81,17 @@ class Feed2Twitter(object):
             self.twitIt(reversed(lista[:5]))
 
 def update():
+    opt = Options()
+    options = opt.parse()
     conf = ConfigParser()
+    if options.sample_config:
+        from pkg_resources import resource_string
+        foo_config = resource_string(__name__, '../docs/default.cfg.sample')
+        print(foo_config)
+        sys.exit(1)
     configfile =os.path.expanduser('~/.feed2twitter/default.cfg')
     try:
-        fd =  open(configfile, 'r')
+        fd =  open(options.config_filename, 'r')
     except IOError:
         print >>sys.stderr, "File %s not found" % configfile
         sys.exit(2)
